==> org.eclipse.ocl.xtext.base.source_1.0.1.v20150907-1419.jar: org/eclipse/ocl/xtext/base/utilities/BaseCSResource.java <==
/*******************************************************************************
 * Copyright (c) 2010, 2015 Willink Transformations and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     E.D.Willink - initial API and implementation
 *******************************************************************************/
package org.eclipse.ocl.xtext.base.utilities;

import java.util.Map;

import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EReference;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.ocl.pivot.NamedElement;
import org.eclipse.ocl.pivot.internal.utilities.EnvironmentFactoryInternal;
import org.eclipse.ocl.pivot.resource.ASResource;
import org.eclipse.ocl.pivot.resource.CSResource;
import org.eclipse.ocl.pivot.utilities.EnvironmentFactory;
import org.eclipse.ocl.xtext.base.as2cs.AS2CS;
import org.eclipse.ocl.xtext.base.cs2as.CS2AS;
import org.eclipse.xtext.diagnostics.IDiagnosticConsumer;
import org.eclipse.xtext.nodemodel.INode;
import org.eclipse.xtext.util.Triple;

/**
 * BaseResource defines the Xtext-dependent extended interface for a Concrete Syntax resource.
 */
public interface BaseCSResource extends CSResource
{
	/**
	 * Add the unresolved reference message for EReference in EObject at INode.
	 */
	void createAndAddDiagnostic(Triple<EObject, EReference, INode> triple);

	/**
	 * Create the AS2CS converter for the cs2asResourceMap conversions using metamodelManager.
	 */
	@NonNull AS2CS createAS2CS(@NonNull Map<? extends BaseCSResource, ? extends ASResource> cs2asResourceMap, @NonNull EnvironmentFactoryInternal environmentFactory);

	/**
	 * Create the CS2AS converter for the cs2asResourceMap conversions using metamodelManager.
	 */
	@NonNull CS2AS createCS2AS(@NonNull EnvironmentFactoryInternal environmentFactory, @NonNull ASResource asResource);

	/**
	 * Dispose of this CSResource and its conversion facilities. This frees up resources after conversion to AS but loses the
	 * required source visibility for debugging.
	 */
	void dispose();

	/**
	 * Return the CS2AS adapter for this resource, or null if none in use.
	 */

	@Nullable CS2AS findCS2AS();

	/**
	 * Return the eContentType to be used when creating an AS resource.
	 */
	@NonNull String getASContentType();

	/**
	 * Return the Abstract Syntax URI for the fiven Concrete Syntax URI.
	 */
	@NonNull URI getASURI(@NonNull URI csURI);

	@NonNull CS2AS getCS2AS();

	/**
	 * Return the CS2AS adapter for this resource.
	 * If no CS2AS adapter installed, one is created and installed using the provided metamodelManager,
	 * which if null is also created. 
	 */
	@NonNull CS2AS getCS2AS(@NonNull EnvironmentFactoryInternal environmentFactory, @NonNull ASResource asResource);
	
	/**
	 * Return the name of the editor for use in diagnostics.
	 */
	@NonNull String getEditorName();

	@NonNull EnvironmentFactory getEnvironmentFactory();

	/**
	 * Return a non-null NamedElement if element is able to be accessed by a qualified path; Other elements must use a quoted URI.
	 */
	@Nullable NamedElement isPathable(@NonNull EObject element);

	/**
	 * Return a uri against the URI of this CS resource.
	 */
	@NonNull URI resolve(@NonNull URI uri);

	void update(@NonNull IDiagnosticConsumer diagnosticsConsumer);

}

==> org.eclipse.ocl.xtext.base.source_1.1.0.v20160521-2033.jar: org/eclipse/ocl/xtext/base/utilities/BaseCSResource.java <==
/*******************************************************************************
 * Copyright (c) 2010, 2015 Willink Transformations and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     E.D.Willink - initial API and implementation
 *******************************************************************************/
package org.eclipse.ocl.xtext.base.utilities;

import java.util.Map;

import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EReference;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.ocl.pivot.NamedElement;
import org.eclipse.ocl.pivot.internal.utilities.EnvironmentFactoryInternal;
import org.eclipse.ocl.pivot.resource.ASResource;
import org.eclipse.ocl.pivot.resource.CSResource;
import org.eclipse.ocl.pivot.utilities.EnvironmentFactory;
import org.eclipse.ocl.xtext.base.as2cs.AS2CS;
import org.eclipse.ocl.xtext.base.cs2as.CS2AS;
import org.eclipse.xtext.diagnostics.IDiagnosticConsumer;
import org.eclipse.xtext.nodemodel.INode;
import org.eclipse.xtext.util.Triple;

/**
 * BaseResource defines the Xtext-dependent extended interface for a Concrete Syntax resource.
 */
public interface BaseCSResource extends CSResource.CSResourceExtension
{
	/**
	 * Add the unresolved reference message for EReference in EObject at INode.
	 */
	void createAndAddDiagnostic(Triple<EObject, EReference, INode> triple);

	/**
	 * Create the AS2CS converter for the cs2asResourceMap conversions using metamodelManager.
	 */
	@NonNull AS2CS createAS2CS(@NonNull Map<? extends BaseCSResource, ? extends ASResource> cs2asResourceMap, @NonNull EnvironmentFactoryInternal environmentFactory);

	/**
	 * Create the CS2AS converter for the cs2asResourceMap conversions using metamodelManager.
	 */
	@NonNull CS2AS createCS2AS(@NonNull EnvironmentFactoryInternal environmentFactory, @NonNull ASResource asResource);

	/**
	 * Return the CS2AS adapter for this resource, or null if none in use.
	 */

	@Nullable CS2AS findCS2AS();

	/**
	 * Return the eContentType to be used when creating an AS resource.
	 */
	@NonNull String getASContentType();

	/**
	 * Return the Abstract Syntax URI for the fiven Concrete Syntax URI.
	 */
	@NonNull URI getASURI(@NonNull URI csURI);

	@NonNull CS2AS getCS2AS();

	/**
	 * Return the CS2AS adapter for this resource.
	 * If no CS2AS adapter installed, one is created and installed using the provided metamodelManager,
	 * which if null is also created. 
	 */
	@NonNull CS2AS getCS2AS(@NonNull EnvironmentFactoryInternal environmentFactory, @NonNull ASResource asResource);
	
	/**
	 * Return the name of the editor for use in diagnostics.
	 */
	@NonNull String getEditorName();

	@NonNull EnvironmentFactory getEnvironmentFactory();

	/**
	 * Return a non-null NamedElement if element is able to be accessed by a qualified path; Other elements must use a quoted URI.
	 */
	@Nullable NamedElement isPathable(@NonNull EObject element);

	/**
	 * Return a uri against the URI of this CS resource.
	 */
	@NonNull URI resolve(@NonNull URI uri);

	void update(@NonNull IDiagnosticConsumer diagnosticsConsumer);

}
